@@ -1,6 +1,7 @@
+from copy import deepcopy
 import re
-from typing import Union, Optional, Iterable
-from sigma.modifiers import SigmaContainsModifier
+from typing import Union, Optional, Iterable, Tuple
+from sigma.modifiers import SigmaContainsModifier, SigmaStartswithModifier, SigmaEndswithModifier
 from sigma.processing.conditions import LogsourceCondition
 from sigma.processing.transformations import FieldMappingTransformation, ValueTransformation, \
     DetectionItemTransformation
@@ -247,7 +248,7 @@ stix_2_0_mapping = {
         "process:binary_ref.name"
     ],
     "ImagePath": [
-        "process:binary_ref.parent_directory_ref.path.name"
+        "process:binary_ref.parent_directory_ref.path"
     ],
     "SourceImage": [
         "process:binary_ref.name"
@@ -456,6 +457,9 @@ stix_shifter_mapping = {
     "pam_message": [
         "x-oca-event:action"
     ],
+    "PipeName": [
+        "x-oca-event:pipe_name"
+    ],
     "cs-host": [
         "x-oca-asset:hostname",
         "domain-name:value"
@@ -498,8 +502,7 @@ stix_shifter_mapping = {
         "x-qradar:credibility"
     ],
     "Device": [
-        "x-qradar:device_type",
-        "file:name"
+        "x-qradar:device_type"
     ],
     "devicetype": [
         "x-qradar:device_type"
@@ -569,14 +572,17 @@ class NumericValueCastingTransformation(ValueTransformation):
 
 class LinuxArgumentsCommandLineLikeTransformation(ValueTransformation):
 
+    argument_regex_pattern = r"a[0-9]+"  # a0, a1, a2, ...
+
     def apply_value(self, field: str, val: SigmaString) -> Optional[Union[SigmaType, Iterable[SigmaType]]]:
-        return SigmaString(' ' + str(val) + ' ')
+        if re.match(self.argument_regex_pattern, field):
+            return SigmaString(' ' + str(val) + ' ')
+        return val
 
     def apply_detection_item(self, detection_item: SigmaDetectionItem) -> Optional[
             Union[SigmaDetection, SigmaDetectionItem]]:
         super().apply_detection_item(detection_item)
-        argument_regex_pattern = r"a[0-9]+"  # a0, a1, a2, ...
-        if re.match(argument_regex_pattern, detection_item.field):
+        if re.match(self.argument_regex_pattern, detection_item.field):
             if SigmaContainsModifier not in detection_item.modifiers:
                 new_detection_item = SigmaDetectionItem(
                     field=detection_item.field,
@@ -588,59 +594,148 @@ class LinuxArgumentsCommandLineLikeTransformation(ValueTransformation):
         return detection_item
 
 
-class SplitImageFieldWindowsTransformation(DetectionItemTransformation):
+class SplitImageFieldTransformation:
+    def __init__(self, platform: str):
+        self.backslash_token = '\\' if platform == 'windows' else '/'
 
-    @staticmethod
-    def _create_filename_detection(full_path: str, detection_item: SigmaDetectionItem) -> Optional[SigmaDetection]:
-        full_path_arr = full_path.split('\\')
-        if len(full_path_arr) > 1:
-            directory_path_arr = full_path_arr[:-1]
-            directory_path = '\\'.join(directory_path_arr)
-            filename = full_path_arr[-1]
+    file_type = 'file'
+    directory_type = 'directory'
 
-            filename_detection_item = SigmaDetectionItem(
-                field='file:name',
-                value=[SigmaString(filename)],
-                modifiers=detection_item.modifiers,
-            )
-            directory_detection_item = SigmaDetectionItem(
-                field='file:parent_directory_ref.path',
-                value=[SigmaString(directory_path)],
-                modifiers=detection_item.modifiers,
-            )
-            return SigmaDetection(
-                detection_items=[
-                    filename_detection_item,
-                    directory_detection_item
-                ]
-            )
-        return SigmaDetection(
-            detection_items=[
-                SigmaDetectionItem(
-                    field=detection_item.field,
-                    value=[SigmaString(full_path)],
-                    modifiers=detection_item.modifiers,
-                )
-            ]
+    fields_to_split_kb = {
+        'file:name': {
+            file_type: 'file:name',
+            directory_type: 'file:parent_directory_ref.path'
+        },
+        'process:binary_ref.name': {
+            file_type: 'process:binary_ref.name',
+            directory_type: 'process:binary_ref.parent_directory_ref.path'
+        },
+        'process:parent_ref.binary_ref.name': {
+            file_type: 'process:parent_ref.binary_ref.name',
+            directory_type: 'process:parent_ref.binary_ref.parent_directory_ref.path'
+        }
+    }
+
+    wildcard_token = '*'
+
+    def _clean_value(self, value: str, modifiers: list) -> str:
+        if (SigmaContainsModifier in modifiers or SigmaEndswithModifier in modifiers) \
+                and value.startswith(self.wildcard_token):
+            value = value[1:]
+        if SigmaContainsModifier in modifiers or SigmaStartswithModifier in modifiers:
+            if value.endswith(self.wildcard_token):
+                value = value[:-1]
+        return value
+
+    def _extract_directory_path_and_filename_from_value(self, value: str) -> Optional[Tuple[Optional[str], Optional[str]]]:
+        if value.endswith(self.backslash_token):
+            # if the value ends with a backslash, it is a directory path
+            return value, None
+        value_arr = value.split(self.backslash_token)
+        value_arr_dropped_empty = list(filter(lambda x: x != '', value_arr))
+
+        if len(value_arr_dropped_empty) == 1:
+            # if the value contains only one element, it is a filename
+            return None, value_arr_dropped_empty[0]
+
+        if len(value_arr_dropped_empty) > 1:
+            # if the value contains more than one element, the last element is a filename,
+            # and the rest is a directory path
+            filename = value_arr_dropped_empty[-1]
+            directory_path_arr = value_arr_dropped_empty[:-1]
+            directory_path = self.backslash_token.join(directory_path_arr)
+            if value.startswith(self.backslash_token):
+                directory_path = self.backslash_token + directory_path
+            return directory_path, filename
+
+    def _create_detection_item(self, value: str, field: str, field_type: str, original_detection_item: SigmaDetectionItem,
+                               two_parts=False) -> SigmaDetectionItem:
+
+        modifiers = deepcopy(original_detection_item.modifiers)
+
+        if two_parts:
+            if SigmaContainsModifier in modifiers:
+                if field_type == self.file_type:
+                    modifiers.remove(SigmaContainsModifier)
+                    modifiers.append(SigmaStartswithModifier)
+                elif field_type == self.directory_type:
+                    modifiers.remove(SigmaContainsModifier)
+                    modifiers.append(SigmaEndswithModifier)
+            elif SigmaStartswithModifier in modifiers:
+                if field_type == self.directory_type:
+                    modifiers.remove(SigmaStartswithModifier)
+            elif SigmaEndswithModifier in modifiers:
+                if field_type == self.file_type:
+                    modifiers.remove(SigmaEndswithModifier)
+
+        return SigmaDetectionItem(
+            field=field,
+            modifiers=modifiers,
+            value=[SigmaString(value)],
         )
 
-    def apply_detection_item(self, detection_item: SigmaDetectionItem) -> Optional[
-            Union[SigmaDetection, SigmaDetectionItem]]:
+    def _produce_detection(self, value: str, detection_item: SigmaDetectionItem) -> Optional[SigmaDetection]:
+        directory_path, filename = self._extract_directory_path_and_filename_from_value(value)
 
-        if detection_item.field == 'file:name':
+        if directory_path is None and filename is None:
+            return None
+
+        directory_path_detection_item = None
+        filename_detection_item = None
+
+        if directory_path is not None:
+            directory_field = self.fields_to_split_kb[detection_item.field]['directory']
+            directory_path_detection_item = self._create_detection_item(directory_path,
+                                                                        directory_field,
+                                                                        self.directory_type,
+                                                                        detection_item,
+                                                                        filename is not None)
+
+        if filename is not None:
+            filename_field = self.fields_to_split_kb[detection_item.field]['file']
+            filename_detection_item = self._create_detection_item(filename,
+                                                                  filename_field,
+                                                                  self.file_type,
+                                                                  detection_item,
+                                                                  directory_path is not None)
+
+        filtered_detections = list(filter(lambda x: x is not None,
+                                          [filename_detection_item, directory_path_detection_item]))
+        return SigmaDetection(detection_items=filtered_detections) if len(filtered_detections) > 0 else None
+
+    def apply_detection_item(self, detection_item: SigmaDetectionItem) -> Optional[
+        Union[SigmaDetection, SigmaDetectionItem]]:
+
+        if detection_item.field in self.fields_to_split_kb.keys():
             if isinstance(detection_item.value, list):
                 aggregated_detections = []
-                values = detection_item.value
-                for value in values:
-                    filename_detection = self._create_filename_detection(str(value),
-                                                                         detection_item)
-                    aggregated_detections.append(filename_detection)
-                return SigmaDetection(
-                    detection_items=aggregated_detections
-                )
+                for value in detection_item.value:
+                    value_raw = self._clean_value(str(value), detection_item.modifiers)
+                    produced_detection = self._produce_detection(value_raw,
+                                                                 detection_item)
+                    if produced_detection is not None:
+                        aggregated_detections.append(produced_detection)
+                return SigmaDetection(detection_items=aggregated_detections)
+            else:
+                # TODO - when is this case happening?
+                raise ValueError(f"Value of field {detection_item.field} is not a list")
         return detection_item
 
 
+class SplitImageFieldLinuxTransformation(DetectionItemTransformation):
+    def apply_detection_item(self, detection_item: SigmaDetectionItem) -> Optional[
+            Union[SigmaDetection, SigmaDetectionItem]]:
+        base = SplitImageFieldTransformation(platform="linux")
+        return base.apply_detection_item(detection_item)
+
+
+class SplitImageFieldWindowsTransformation(DetectionItemTransformation):
+    def apply_detection_item(self, detection_item: SigmaDetectionItem) -> Optional[
+            Union[SigmaDetection, SigmaDetectionItem]]:
+        base = SplitImageFieldTransformation(platform="windows")
+        return base.apply_detection_item(detection_item)
+
+
 def stix_2_0() -> ProcessingPipeline:
     """This is a pipeline that maps fields to the STIX 2.0 format."""
     return ProcessingPipeline(
@@ -673,6 +768,15 @@ def stix_2_0() -> ProcessingPipeline:
                     )
                 ]
             ),
+            ProcessingItem(
+                identifier="image_split_linux",
+                transformation=SplitImageFieldLinuxTransformation(),
+                rule_conditions=[
+                    LogsourceCondition(
+                        product="linux",
+                    )
+                ]
+            ),
         ],
     )
 
